@@ -1,4 +1,5 @@
-from tensorflow.python import training
+import tensorflow as tf
+from tensorflow.keras import layers, Model, Sequential
 from fusionlab.segmentation.base import TFSegmentationModel
 
 
